<?php
/**
 * Plugin Name: Title2Image
 * Plugin URI: https://arajans.com
 * Description: Automatically renames images with meaningless or generic filenames to the post title.
 * Version: 2.0
 * Author: Siyar Kendirci
 * Author URI: https://arajans.com
 * License: GPLv2 or later
 * Text Domain: title2image
 * Domain Path: /languages
 * Requires at least: 5.0
 * Requires PHP: 7.0
 */

defined('ABSPATH') || exit;

// Plugin constants
define('TITLE2IMAGE_VERSION', '2.0');
define('TITLE2IMAGE_FILE', __FILE__);
define('TITLE2IMAGE_PATH', plugin_dir_path(__FILE__));
define('TITLE2IMAGE_URL', plugin_dir_url(__FILE__));
define('TITLE2IMAGE_PATTERNS', serialize(array(
    // Basic patterns
    '/^[0-9]+$/',                          // Numbers only
    '/^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$/i', // UUID
    '/^[0-9a-f]{32}$/i',                   // MD5 hash
    '/^[0-9]{10,}$/',                      // 10+ digit numbers
    
    // Phone and camera images
    '/^IMG[-_][0-9]+$/i',                  // IMG-12345 or IMG_12345
    '/^IMG[-_][0-9]IMG[-_][0-9]+$/i',      // IMG-12345 or IMG_12345
    '/^IMG[0-9]+$/i',                      // IMG12345
    '/^DSC[-_][0-9]+$/i',                  // DSC-12345 or DSC_12345
    '/^DSC[0-9]+$/i',                      // DSC12345
    '/^PXL[-_][0-9]+$/i',                  // PXL-20231012
    '/^P[0-9]+$/i',                        // P100054
    '/^Photo[-_][0-9]+$/i',                // Photo-12345
    '/^Camera[-_][0-9]+$/i',               // Camera-12345
    '/^Screenshot_[-0-9]+$/i',             // Screenshot_2023-10-12
    '/^Snapchat-[-0-9]+$/i',               // Snapchat-20231012
    '/^FB_IMG_[0-9]+$/i',                  // FB_IMG_12345
    '/^MVIMG_[0-9]+$/i',                   // MVIMG_20231012
    '/^100[A-Za-z][A-Za-z][A-Za-z][0-9]+$/i', // 100ABC123 (Canon format)
    
    // WhatsApp special formats
    '/^IMG-\d{8}-WA\d{4}$/i',             // IMG-20250523-WA0109
    '/^VID-\d{8}-WA\d{4}$/i',             // VID-20250523-WA0109
    '/^PXL-\d{8}-\d{6}$/i',               // PXL-20250523-1234
    '/^whatsapp_image/i',                  // whatsapp_image...
    '/^Signal-[-0-9]+$/i',                 // Signal-2023-10-12
    '/^Telegram\sVideo/i',                 // Telegram Video...
    '/^Picsart_/',                         // Picsart_...
    '/^Instagram_/',                       // Instagram_...
    '/^TikTok_[-0-9]+$/i',                // TikTok_20231012
    
    // Other
    '/^unnamed/',                          // unnamed...
    '/^image[-_][0-9]+$/i',                // image-12345
    '/^foto[-_][0-9]+$/i',                 // foto-12345
    '/^resim[-_][0-9]+$/i',                // resim-12345
    '/^temp[-_][0-9]+$/i',                 // temp-12345
    '/^export[0-9]+$/i',                   // export12345
    '/^copy[-_][0-9]+$/i',                 // copy-12345
    '/^download[0-9]+$/i',                 // download12345
)));

/**
 * Load plugin text domain for translations
 */
function title2image_load_textdomain() {
    load_plugin_textdomain('title2image', false, dirname(plugin_basename(__FILE__)) . '/languages');
}
add_action('plugins_loaded', 'title2image_load_textdomain');

/**
 * Plugin activation
 */
function title2image_activate() {
    add_option('title2image_scan_status', 'inactive');
    
    // Create necessary files if they don't exist
    $upload_dir = wp_upload_dir();
    if (!file_exists($upload_dir['basedir'])) {
        wp_mkdir_p($upload_dir['basedir']);
    }
    
    // Flush rewrite rules
    flush_rewrite_rules();
}
register_activation_hook(__FILE__, 'title2image_activate');

/**
 * Plugin deactivation
 */
function title2image_deactivate() {
    // Clean up if needed
    flush_rewrite_rules();
}
register_deactivation_hook(__FILE__, 'title2image_deactivate');

/**
 * Admin menu
 */
function title2image_admin_menu() {
    add_media_page(
        __('Title2Image Analysis', 'title2image'),
        __('Image Analysis', 'title2image'),
        'manage_options',
        'title2image-scan',
        'title2image_scan_page'
    );
}
add_action('admin_menu', 'title2image_admin_menu');

/**
 * Image upload pre-processing
 * 
 * @param array $file File data array
 * @return array Modified file data array
 */
function title2image_rename_upload($file) {
    $filename = pathinfo($file['name'], PATHINFO_FILENAME);
    $patterns = unserialize(TITLE2IMAGE_PATTERNS);
    
    foreach ($patterns as $pattern) {
        if (preg_match($pattern, $filename)) {
            $post_id = isset($_REQUEST['post_id']) ? (int)$_REQUEST['post_id'] : 0;
            
            if ($post_id > 0) {
                $post_title = get_the_title($post_id);
                if (!empty($post_title)) {
                    $file['name'] = sanitize_file_name($post_title) . '.' . pathinfo($file['name'], PATHINFO_EXTENSION);
                    break;
                }
            }
        }
    }
    return $file;
}
add_filter('wp_handle_upload_prefilter', 'title2image_rename_upload');

/**
 * Update attachments when post is saved
 * 
 * @param int $post_id Post ID
 * @param WP_Post $post Post object
 * @param bool $update Whether this is an update
 */
function title2image_update_attachments($post_id, $post, $update) {
    if (defined('DOING_AUTOSAVE') && DOING_AUTOSAVE) {
        return;
    }
    
    if (wp_is_post_revision($post_id)) {
        return;
    }
    
    if ($post->post_status === 'auto-draft' || $post->post_status === 'trash') {
        return;
    }
    
    if (empty($post->post_title)) {
        return;
    }

    $attachments = get_attached_media('', $post_id);
    $patterns = unserialize(TITLE2IMAGE_PATTERNS);

    foreach ($attachments as $attachment) {
        $current_file = get_attached_file($attachment->ID);
        if (!$current_file || !file_exists($current_file)) {
            continue;
        }
        
        $current_filename = pathinfo($current_file, PATHINFO_FILENAME);
        
        foreach ($patterns as $pattern) {
            if (preg_match($pattern, $current_filename)) {
                title2image_rename_file($attachment->ID, $post->post_title);
                break;
            }
        }
    }
}
add_action('save_post', 'title2image_update_attachments', 10, 3);

/**
 * File renaming function
 * 
 * @param int $attachment_id Attachment ID
 * @param string $new_name New filename
 * @return bool Success or failure
 */
function title2image_rename_file($attachment_id, $new_name) {
    $current_file = get_attached_file($attachment_id);
    
    if (!$current_file || !file_exists($current_file)) {
        return false;
    }
    
    $current_filename = pathinfo($current_file, PATHINFO_FILENAME);
    $extension = pathinfo($current_file, PATHINFO_EXTENSION);
    
    $new_filename = sanitize_file_name($new_name);
    $new_file = str_replace($current_filename, $new_filename, $current_file);
    
    // Create unique filename
    $counter = 1;
    $base_file = $new_file;
    while (file_exists($new_file)) {
        $new_file = pathinfo($base_file, PATHINFO_DIRNAME) . '/' . 
                    $new_filename . '-' . $counter . '.' . $extension;
        $counter++;
    }
    
    if (rename($current_file, $new_file)) {
        // Update metadata
        update_attached_file($attachment_id, $new_file);
        
        // Update GUID
        global $wpdb;
        $wpdb->update(
            $wpdb->posts,
            array('guid' => wp_get_attachment_url($attachment_id)),
            array('ID' => $attachment_id)
        );
        
        // Regenerate media metadata
        $metadata = wp_generate_attachment_metadata($attachment_id, $new_file);
        wp_update_attachment_metadata($attachment_id, $metadata);
        
        /**
         * Action hook fired after a file is renamed
         *
         * @param int $attachment_id The attachment ID
         * @param string $new_file The new file path
         * @param string $current_file The old file path
         */
        do_action('title2image_after_rename', $attachment_id, $new_file, $current_file);
        
        return true;
    }
    return false;
}

/**
 * Analysis page
 */
function title2image_scan_page() {
    // Security check
    if (!current_user_can('manage_options')) {
        wp_die(__('You do not have sufficient permissions!', 'title2image'));
    }

    // Date filters
    $current_year = isset($_POST['filter_year']) ? intval($_POST['filter_year']) : 0;
    $current_month = isset($_POST['filter_month']) ? intval($_POST['filter_month']) : 0;
    
    // Start scanning
    if (isset($_POST['start_scan'])) {
        check_admin_referer('title2image_scan_action', 'title2image_nonce');
        update_option('title2image_scan_status', 'scanning');
        $scan_results = title2image_perform_scan($current_year, $current_month);
        update_option('title2image_scan_results', $scan_results);
        update_option('title2image_scan_status', 'completed');
    }

    // Renaming
    if (isset($_POST['rename_files']) && !empty($_POST['attachment_ids'])) {
        check_admin_referer('title2image_rename_action', 'title2image_rename_nonce');
        $renamed_count = 0;
        foreach ($_POST['attachment_ids'] as $attachment_id) {
            $attachment_id = intval($attachment_id);
            $attachment = get_post($attachment_id);
            if ($attachment && $attachment->post_parent) {
                $post_title = get_the_title($attachment->post_parent);
                if (title2image_rename_file($attachment_id, $post_title)) {
                    $renamed_count++;
                }
            }
        }
        echo '<div class="notice notice-success"><p>' . 
            sprintf(_n('%d image successfully renamed!', '%d images successfully renamed!', $renamed_count, 'title2image'), $renamed_count) . 
            '</p></div>';
    }

    // Get results
    $scan_status = get_option('title2image_scan_status');
    $scan_results = ($scan_status === 'completed') ? get_option('title2image_scan_results', array()) : array();
    
    // Date filter options
    $years = title2image_get_attachment_years();
    $months = array(
        1 => __('January', 'title2image'), 
        2 => __('February', 'title2image'), 
        3 => __('March', 'title2image'), 
        4 => __('April', 'title2image'),
        5 => __('May', 'title2image'), 
        6 => __('June', 'title2image'), 
        7 => __('July', 'title2image'), 
        8 => __('August', 'title2image'),
        9 => __('September', 'title2image'), 
        10 => __('October', 'title2image'), 
        11 => __('November', 'title2image'), 
        12 => __('December', 'title2image')
    );
    ?>
    <div class="wrap title2image-wrap">
        <h1><?php _e('Title2Image - Advanced Image Analysis Panel', 'title2image'); ?></h1>
        
        <?php if ($scan_status === 'scanning'): ?>
            <div class="notice notice-info">
                <p><?php _e('Scanning in progress... Please wait.', 'title2image'); ?></p>
            </div>
        <?php endif; ?>
        
        <div class="title2image-dashboard">
            <div class="title2image-card">
                <h2><?php _e('Filter Options', 'title2image'); ?></h2>
                <form method="post" id="scan-form">
                    <?php wp_nonce_field('title2image_scan_action', 'title2image_nonce'); ?>
                    <div class="title2image-filters">
                        <div>
                            <label for="filter_year"><?php _e('Year:', 'title2image'); ?></label>
                            <select name="filter_year" id="filter_year">
                                <option value="0"><?php _e('All Years', 'title2image'); ?></option>
                                <?php foreach ($years as $year): ?>
                                    <option value="<?php echo esc_attr($year); ?>" <?php selected($current_year, $year); ?>>
                                        <?php echo esc_html($year); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        
                        <div>
                            <label for="filter_month"><?php _e('Month:', 'title2image'); ?></label>
                            <select name="filter_month" id="filter_month">
                                <option value="0"><?php _e('All Months', 'title2image'); ?></option>
                                <?php foreach ($months as $num => $name): ?>
                                    <option value="<?php echo esc_attr($num); ?>" <?php selected($current_month, $num); ?>>
                                        <?php echo esc_html($name); ?>
                                    </option>
                                <?php endforeach; ?>
                            </select>
                        </div>
                        
                        <div>
                            <input type="submit" name="start_scan" class="button button-primary" value="<?php _e('Filter and Analyze', 'title2image'); ?>">
                        </div>
                    </div>
                </form>
            </div>
            
            <?php if (!empty($scan_results)): ?>
                <div class="title2image-card">
                    <h2>
                        <?php 
                        echo sprintf(
                            __('Found Images: %d (%s/%s)', 'title2image'), 
                            count($scan_results),
                            $current_year ? $current_year : __('All Years', 'title2image'),
                            $current_month ? $months[$current_month] : __('All Months', 'title2image')
                        ); 
                        ?>
                    </h2>
                    
                    <form method="post">
                        <?php wp_nonce_field('title2image_rename_action', 'title2image_rename_nonce'); ?>
                        <div class="tablenav top">
                            <div class="alignleft actions">
                                <input type="submit" name="rename_files" class="button button-primary" value="<?php _e('Rename Selected Images', 'title2image'); ?>">
                                <span class="description"><?php _e('Only images attached to posts can be renamed', 'title2image'); ?></span>
                            </div>
                            <div class="tablenav-pages">
                                <span class="displaying-num"><?php echo sprintf(_n('%s item', '%s items', count($scan_results), 'title2image'), number_format_i18n(count($scan_results))); ?></span>
                            </div>
                        </div>
                        
                        <table class="wp-list-table widefat fixed striped title2image-table">
                            <thead>
                                <tr>
                                    <th class="check-column"><input type="checkbox" id="select-all"></th>
                                    <th class="column-image"><?php _e('Image', 'title2image'); ?></th>
                                    <th class="column-name"><?php _e('Current Name', 'title2image'); ?></th>
                                    <th class="column-size"><?php _e('Size', 'title2image'); ?></th>
                                    <th class="column-date"><?php _e('Upload Date', 'title2image'); ?></th>
                                    <th class="column-post"><?php _e('Attached Post', 'title2image'); ?></th>
                                    <th class="column-newname"><?php _e('New Name', 'title2image'); ?></th>
                                </tr>
                            </thead>
                            <tbody>
                                <?php foreach ($scan_results as $result): 
                                    $file_info = pathinfo($result['file']);
                                    $file_size = size_format(filesize($result['file']));
                                    $upload_date = date_i18n(get_option('date_format'), strtotime($result['post_date']));
                                ?>
                                    <tr>
                                        <td>
                                            <?php if ($result['post_parent']): ?>
                                                <input type="checkbox" name="attachment_ids[]" value="<?php echo esc_attr($result['ID']); ?>">
                                            <?php endif; ?>
                                        </td>
                                        <td><?php echo wp_get_attachment_image($result['ID'], array(80, 80)); ?></td>
                                        <td>
                                            <div class="filename"><?php echo esc_html($file_info['basename']); ?></div>
                                            <div class="row-actions">
                                                <a href="<?php echo esc_url(get_edit_post_link($result['ID'])); ?>"><?php _e('Edit', 'title2image'); ?></a> | 
                                                <a href="<?php echo esc_url(wp_get_attachment_url($result['ID'])); ?>" target="_blank"><?php _e('View', 'title2image'); ?></a>
                                            </div>
                                        </td>
                                        <td><?php echo esc_html($file_size); ?></td>
                                        <td><?php echo esc_html($upload_date); ?></td>
                                        <td>
                                            <?php if ($result['post_parent']): ?>
                                                <a href="<?php echo esc_url(get_edit_post_link($result['post_parent'])); ?>">
                                                    <?php echo esc_html(get_the_title($result['post_parent'])); ?>
                                                </a>
                                            <?php else: ?>
                                                <em><?php _e('No attached post', 'title2image'); ?></em>
                                            <?php endif; ?>
                                        </td>
                                        <td>
                                            <?php if ($result['post_parent']): ?>
                                                <?php 
                                                    $new_name = sanitize_file_name(get_the_title($result['post_parent'])); 
                                                    $new_full = $new_name . '.' . $file_info['extension'];
                                                ?>
                                                <div class="rename-field">
                                                    <input type="text" value="<?php echo esc_attr($new_full); ?>" class="new-filename" data-original="<?php echo esc_attr($new_full); ?>">
                                                    <div class="rename-actions">
                                                        <button type="button" class="copy-filename button" data-clipboard-text="<?php echo esc_attr($new_full); ?>" title="<?php _e('Copy filename', 'title2image'); ?>"><span class="dashicons dashicons-clipboard"></span></button>
                                                        <button type="button" class="reset-filename button" title="<?php _e('Reset to original', 'title2image'); ?>"><span class="dashicons dashicons-undo"></span></button>
                                                    </div>
                                                </div>
                                            <?php else: ?>
                                                <em><?php _e('Not applicable', 'title2image'); ?></em>
                                            <?php endif; ?>
                                        </td>
                                    </tr>
                                <?php endforeach; ?>
                            </tbody>
                        </table>
                        
                        <div class="tablenav bottom">
                            <div class="alignleft actions">
                                <input type="submit" name="rename_files" class="button button-primary" value="<?php _e('Rename Selected Images', 'title2image'); ?>">
                            </div>
                        </div>
                    </form>
                </div>
            <?php endif; ?>
        </div>
    </div>
    <?php
}

/**
 * Media scan function
 * 
 * @param int $year Year filter
 * @param int $month Month filter
 * @return array Scan results
 */
function title2image_perform_scan($year = 0, $month = 0) {
    global $wpdb;
    
    $query = "
        SELECT p.ID, pm.meta_value AS file, p.post_parent, p.post_date
        FROM {$wpdb->posts} p
        INNER JOIN {$wpdb->postmeta} pm ON p.ID = pm.post_id
        WHERE p.post_type = 'attachment'
        AND pm.meta_key = '_wp_attached_file'
        AND p.post_mime_type LIKE 'image/%'
    ";
    
    // Date filters
    $conditions = array();
    $params = array();
    
    if ($year > 0) {
        $conditions[] = "YEAR(p.post_date) = %d";
        $params[] = $year;
    }
    
    if ($month > 0) {
        $conditions[] = "MONTH(p.post_date) = %d";
        $params[] = $month;
    }
    
    if (!empty($conditions)) {
        $query .= " AND " . implode(" AND ", $conditions);
    }
    
    if (!empty($params)) {
        $query = $wpdb->prepare($query, $params);
    }
    
    $attachments = $wpdb->get_results($query, ARRAY_A);
    $results = array();
    $patterns = unserialize(TITLE2IMAGE_PATTERNS);
    
    foreach ($attachments as $attachment) {
        $filename = pathinfo($attachment['file'], PATHINFO_FILENAME);
        $matched = false;
        
        foreach ($patterns as $pattern) {
            if (preg_match($pattern, $filename)) {
                $matched = true;
                break;
            }
        }
        
        if ($matched) {
            // Get full file path
            $upload_dir = wp_upload_dir();
            $full_file = $upload_dir['basedir'] . '/' . $attachment['file'];
            
            // Check if file exists
            if (!file_exists($full_file)) {
                // Try to find the file with case-insensitive search
                $dir = pathinfo($full_file, PATHINFO_DIRNAME);
                $base = pathinfo($full_file, PATHINFO_BASENAME);
                
                if (is_dir($dir)) {
                    $files = scandir($dir);
                    foreach ($files as $file) {
                        if (strtolower($file) === strtolower($base)) {
                            $full_file = $dir . '/' . $file;
                            break;
                        }
                    }
                }
                
                // Skip if file still not found
                if (!file_exists($full_file)) {
                    continue;
                }
            }
            
            $results[] = array(
                'ID' => $attachment['ID'],
                'file' => $full_file,
                'post_parent' => $attachment['post_parent'],
                'post_date' => $attachment['post_date']
            );
        }
    }
    
    return $results;
}

/**
 * Get years function
 * 
 * @return array Years with attachments
 */
function title2image_get_attachment_years() {
    global $wpdb;
    
    $query = "
        SELECT DISTINCT YEAR(post_date) AS year
        FROM {$wpdb->posts}
        WHERE post_type = 'attachment'
        AND post_mime_type LIKE 'image/%'
        ORDER BY year DESC
    ";
    
    $years = $wpdb->get_col($query);
    return $years ? $years : array(date('Y'));
}

/**
 * Admin style and script
 */
function title2image_admin_assets($hook) {
    if ($hook === 'media_page_title2image-scan') {
        // Enqueue dashicons
        wp_enqueue_style('dashicons');
        
        // Style
        wp_enqueue_style(
            'title2image-admin',
            TITLE2IMAGE_URL . 'admin.css',
            array(),
            TITLE2IMAGE_VERSION
        );
        
        // Script
        wp_enqueue_script(
            'title2image-admin',
            TITLE2IMAGE_URL . 'admin.js',
            array('jquery'),
            TITLE2IMAGE_VERSION,
            true
        );
        
        // Localize script
        wp_localize_script(
            'title2image-admin',
            'title2imageL10n',
            array(
                'copied' => __('Copied!', 'title2image'),
                'copy' => __('Copy', 'title2image')
            )
        );
    }
}
add_action('admin_enqueue_scripts', 'title2image_admin_assets');

/**
 * Admin CSS
 */
function title2image_admin_styles() {
    $screen = get_current_screen();
    if ($screen && $screen->id === 'media_page_title2image-scan') {
        echo '<style>
            /* Dashboard layout */
            .title2image-wrap {
                max-width: 1200px;
                margin: 20px auto;
            }
            .title2image-dashboard {
                display: flex;
                flex-direction: column;
                gap: 20px;
            }
            .title2image-card {
                background: #fff;
                border-radius: 8px;
                box-shadow: 0 1px 3px rgba(0,0,0,0.1);
                padding: 20px;
            }
            .title2image-card h2 {
                margin-top: 0;
                padding-bottom: 10px;
                border-bottom: 1px solid #eee;
            }
            
            /* Filter area */
            .title2image-filters {
                display: flex;
                gap: 15px;
                margin-bottom: 10px;
                align-items: flex-end;
            }
            .title2image-filters > div {
                display: flex;
                flex-direction: column;
            }
            .title2image-filters label {
                margin-bottom: 5px;
                font-weight: 600;
                color: #23282d;
            }
            
            /* Table styles */
            .title2image-table {
                border-collapse: collapse;
                width: 100%;
            }
            .title2image-table .check-column {
                width: 2em;
                text-align: center;
            }
            .title2image-table .column-image {
                width: 90px;
            }
            .title2image-table .column-size,
            .title2image-table .column-date {
                width: 10%;
            }
            .title2image-table td img {
                max-width: 80px;
                height: auto;
                border-radius: 4px;
                box-shadow: 0 1px 3px rgba(0,0,0,0.2);
            }
            .filename {
                font-weight: 600;
                margin-bottom: 3px;
                word-break: break-all;
            }
            .row-actions {
                font-size: 12px;
            }
            
            /* Rename field */
            .rename-field {
                display: flex;
                flex-direction: column;
                gap: 5px;
            }
            .new-filename {
                width: 100%;
                padding: 6px 8px;
                border: 1px solid #ddd;
                border-radius: 4px;
                font-size: 13px;
            }
            .rename-actions {
                display: flex;
                gap: 5px;
            }
            .rename-actions .button {
                padding: 0;
                width: 30px;
                height: 30px;
                display: flex;
                align-items: center;
                justify-content: center;
            }
            .rename-actions .button .dashicons {
                font-size: 16px;
                width: 16px;
                height: 16px;
            }
            .rename-actions .button.success {
                background-color: #46b450;
                color: #fff;
                border-color: #46b450;
            }
            
            /* Table navigation */
            .tablenav.top {
                margin-bottom: 15px;
            }
            .tablenav.bottom {
                margin-top: 15px;
            }
            
            /* Responsive */
            @media screen and (max-width: 782px) {
                .title2image-filters {
                    flex-direction: column;
                    gap: 10px;
                }
                .rename-field {
                    max-width: 200px;
                }
                .title2image-table .column-size,
                .title2image-table .column-date {
                    width: auto;
                }
            }
        </style>';
    }
}
add_action('admin_head', 'title2image_admin_styles');

/**
 * Create admin.js file on plugin activation
 */
function title2image_create_admin_js() {
    $js_content = "
jQuery(document).ready(function($) {
    // Select all
    $('#select-all').change(function() {
        $('input[name=\"attachment_ids[]\"]').prop('checked', this.checked);
    });
    
    // Copy buttons
    $('.copy-filename').click(function() {
        var text = $(this).closest('.rename-field').find('.new-filename').val();
        var originalText = $(this).attr('title');
        
        // Copy to clipboard
        navigator.clipboard.writeText(text).then(function() {
            var $button = $(this);
            $button.addClass('success');
            $button.attr('title', title2imageL10n.copied);
            
            setTimeout(function() {
                $button.removeClass('success');
                $button.attr('title', originalText);
            }, 2000);
        }.bind(this));
    });
    
    // Reset filename
    $('.reset-filename').click(function() {
        var $input = $(this).closest('.rename-field').find('.new-filename');
        $input.val($input.data('original'));
    });
    
    // Filter change submits form
    $('#filter_year, #filter_month').change(function() {
        $('#scan-form').submit();
    });
});";

    // Create admin.js file if it doesn't exist
    $js_file = plugin_dir_path(__FILE__) . 'admin.js';
    if (!file_exists($js_file)) {
        file_put_contents($js_file, $js_content);
    }
}
register_activation_hook(__FILE__, 'title2image_create_admin_js');

/**
 * Add donation information
 */
function title2image_donation_notice() {
    $screen = get_current_screen();
    if ($screen && $screen->id === 'media_page_title2image-scan') {
        ?>
        <div class="notice notice-info is-dismissible title2image-donation">
            <h3><?php _e('Support Title2Image Development', 'title2image'); ?></h3>
            <p><?php _e('If you find this plugin useful, please consider supporting its development with a donation:', 'title2image'); ?></p>
            <ul style="margin-left: 20px; list-style-type: disc;">
                <li><strong>PayPal:</strong> info@arajans.com</li>
                <li><strong>USDT:</strong> 0x4f6576e24cc6176b9c300097a55e2402692b5cdf</li>
                <li><strong>BNB:</strong> 0x4f6576e24cc6176b9c300097a55e2402692b5cdf</li>
                <li><strong>Bitcoin:</strong> 1JyuHVjjBjLnCRyYXyeuYyBehBWk6vTM5A</li>
            </ul>
            <p><?php _e('Thank you for your support!', 'title2image'); ?></p>
        </div>
        <?php
    }
}
add_action('admin_notices', 'title2image_donation_notice');

/**
 * Add plugin action links
 * 
 * @param array $links Existing plugin action links
 * @return array Modified plugin action links
 */
function title2image_plugin_action_links($links) {
    $settings_link = '<a href="' . admin_url('upload.php?page=title2image-scan') . '">' . __('Settings', 'title2image') . '</a>';
    array_unshift($links, $settings_link);
    return $links;
}
add_filter('plugin_action_links_' . plugin_basename(__FILE__), 'title2image_plugin_action_links');

/**
 * Add plugin row meta
 * 
 * @param array $links Existing plugin row meta
 * @param string $file Plugin file
 * @return array Modified plugin row meta
 */
function title2image_plugin_row_meta($links, $file) {
    if (plugin_basename(__FILE__) === $file) {
        $donate_link = '<a href="https://arajans.com/donate" target="_blank">' . __('Donate', 'title2image') . '</a>';
        $links[] = $donate_link;
    }
    return $links;
}
add_filter('plugin_row_meta', 'title2image_plugin_row_meta', 10, 2);

